# diagrid operator manifests

Print Conductor operator manifest file

### Description

Print the Kubernetes manifests for deploying the Conductor operator

```
diagrid operator manifests [flags]
```

### Examples

```

  # Generate operator manifests including an auto-generated API Key
  diagrid conductor operator manifests --generate-api-key

  # Generate operator manifests providing a custom API Key
  diagrid conductor operator manifests --api-key <my-api-key>

  # Generate operator manifests setting resource requests and limits, node selector and tolerations
  diagrid conductor operator manifests --resource-limits cpu=300m,memory=500Mi --resource-requests cpu=100m,memory=200Mi -n my-node-label=test,other=test2 -t key=autoscaled,operator=Equal,value=true,effect=NoSchedule -t key=type,operator=Equal,value=highmem,effect=NoSchedule

```

### Options

```
      --additional-ca-certs-path string   Additional CA certificates PEM file path for the cluster. This file will be added to the system CA certs folder on the container.
      --api-key string                    Diagrid Cloud API key
      --generate-api-key                  Automatically generate the API Key for the operator
  -h, --help                              help for manifests
      --http-proxy string                 URL of your http proxy server for the cluster
      --https-proxy string                URL of your https proxy server for the cluster
      --kubernetes-distro string          Kubernetes distribution of target cluster (eks, aks, gke, openshift, local, native) (default "native")
      --kubernetes-version string         Kubernetes version of target cluster (default "1.24.2")
  -l, --labels string                     Kubernetes labels for the operator deployment (e.g. -l env=test,other=test2 )
      --no-proxy string                   Comma separated list of URL to not send through the proxy
  -n, --node-selector string              Kubernetes node selector for the operator deployment (e.g. -n my-node-label=test,other=test2 )
      --platform string                   OS platform of target cluster (default "linux/amd64")
      --resource-limits string            Kubernetes resource limits for the operator deployment (e.g. --resource-limits cpu=300m,memory=500Mi )
      --resource-requests string          Kubernetes resource requests for the operator deployment (e.g. --resource-requests cpu=100m,memory=200Mi )
  -t, --tolerations stringArray           Kubernetes tolerations for the operator deployment (e.g. -t key=autoscaled,operator=Equal,value=true,effect=NoSchedule -t key=type,operator=Equal,value=highmem,effect=NoSchedule )
```

### SEE ALSO

- [diagrid operator](./operator.md)	 - Manage the Conductor operator for Kubernetes
